pub fn from_file<T: DeserializeOwned>(path: impl AsRef<Path>) -> Result<T>Expand description
Open a file and deserialize its root element into T.
pub fn from_file<T: DeserializeOwned>(path: impl AsRef<Path>) -> Result<T>Open a file and deserialize its root element into T.